<?xml version='1.0' encoding="UTF-8" ?>
<!--
 * NAT - An universal Translator
 * Copyright (C) 2005 Bruno Mascret
 * Contact: bmascret@free.fr
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-->

<!-- version: 1.3-b3 -->

<!DOCTYPE xsl:stylesheet
  SYSTEM "mmlents/windob.dtd"
[
  <!ENTITY % table_braille PUBLIC "table braille" "./tablesBraille/Brltab.ent">
  %table_braille;
  <!ENTITY quad    "&ThickSpace;"> <!-- espace -->
  <!ENTITY neq     "&ne;"> <!-- different de -->
  <!ENTITY epsilon "&epsiv;"> <!-- epsilon -->
  <!ENTITY empty "&emptyv;"> <!-- endemble vide -->
  <!ENTITY ldots   "&mldr;"> <!-- points de suspension -->
  <!ENTITY hat     "&Hat;"> <!-- signe d'angle -->
  <!ENTITY espace  "&#254;"><!-- espace à generer-->
  <!ENTITY coupe   "&#255;"><!-- endroit ou on peut couper un equation-->
]>


<xsl:stylesheet version="1.0"
xmlns:xsl='http://www.w3.org/1999/XSL/Transform' 
xmlns:saxon='http://icl.com/saxon'
xmlns:m='http://www.w3.org/1998/Math/MathML'
xmlns:lit='espacelit'
xmlns:doc='espaceDoc'>

<xsl:output method="text" encoding="UTF-8" indent="no"/>

<xsl:variable name="chaine_vide"/>

<xsl:template match="lit">
	<!--<xsl:text>debLit</xsl:text>-->
	<xsl:apply-templates select="@*|*|text()|processing-instruction()" />
	<!--<xsl:text>FinLit</xsl:text>-->
</xsl:template>

<xsl:template match="phrase">
	<xsl:apply-templates />
	<xsl:text>&NewLine;</xsl:text><!--&#13;&#10;</xsl:text>-->
</xsl:template>

<xsl:template match="ponctuation">
	<xsl:choose>
		<!-- chat braille -->
		<xsl:when test=".=')' and (preceding::*[1]='B-')" />
<!-- pts de suspension; -->
     <xsl:when test=".='...' or .='…' or .='&mldr;' or .='&vellip;' or .='&hellip;' or .='&dtdot;' or .='&ldots;' or .='&ctdot;' or .='&utdot;'">
       <xsl:text>&pt256;&pt256;&pt256;</xsl:text>
     </xsl:when>
		<xsl:when test='string(.)="&apos;"'>
			<xsl:text>&pt3;</xsl:text>
		</xsl:when>
		<xsl:when test=".='['">
			<xsl:text>&pt45;&pt236;</xsl:text>
		</xsl:when>
		<xsl:when test=".=']'">
			<xsl:text>&pt356;&pt12;</xsl:text>
		</xsl:when>
		<xsl:when test=".='{'">
			<xsl:text>&pt6;&pt6;&pt236;</xsl:text>
		</xsl:when>
		<xsl:when test=".='}'">
			<xsl:text>&pt356;&pt3;&pt3;</xsl:text>
		</xsl:when>
		<xsl:when test=".='-'">
			<!-- est-ce le signe mathématique - ou un tiret? -->
			<xsl:if test="number(translate(preceding-sibling::*[1],',0','.1')) or number(translate(following-sibling::*[1],',0','.1'))"><!-- conversion des , en . et des 0 en 1 car number(0) et number(NNN,NNN) renvoie faux -->
				<xsl:text>&pt6;</xsl:text>
			</xsl:if>
			<xsl:text>&pt36;</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<!-- utilisation d'une variable pour éviter les pb du translate et des '" -->
			<xsl:variable name="v">
				<xsl:text>&pt2;&pt23;&pt25;&pt256;&pt26;&pt235;&pt2356;&pt2356;&pt2356;&pt2356;&pt2356;&pt2356;&pt2356;&pt3;&pt3;&pt3;&pt3;&pt236;&pt356;</xsl:text>
			</xsl:variable>
			<xsl:value-of select="translate(string(.),',;:.?!&quot;«»“”‘’&lsquo;&rsquo;&acute;&prime;()',string($v))"/>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:if test="not (local-name(following::*[1])='phrase') and not(contains('([{«“‘&lsquo;',.))"><!-- RAF:à améliorer pour les guillemets et apos ouvrantssimples -->
		<xsl:text> </xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template match="mot">
	<xsl:choose>
		<xsl:when test="string-length(.)=0">
		</xsl:when>
		<!-- chat braille -->
		<xsl:when test=".='B-' and following::*[1]=')'">
			<xsl:text>&pt46;&pt13;&pt25;&pt135;</xsl:text>
		</xsl:when>
		<!-- numérique (ou trait d'union) -->
		<xsl:when test="contains(translate(.,'0123456789-+×÷=&sup2;&sup3;','11111111111111111'),'1')">
			<xsl:choose>
				<xsl:when test="contains(.,'-') and not(substring(.,1,1) = '-') and not(contains(translate(.,'0123456789+×÷=&sup2;&sup3;','1111111111111111'),'1'))"><!-- trait d'union-->
					<xsl:call-template name="majuscule">
						<xsl:with-param name="mot" select="." />
						<xsl:with-param name="prefixe" select="0" />
						<xsl:with-param name="position" select="1" />
					</xsl:call-template>
					<!-- espaces -->
					<xsl:choose>
						<xsl:when test="local-name(following-sibling::*[1])='mot'">
							<xsl:text> </xsl:text>
						</xsl:when>
						<!-- espaces avec les pponctuations -->
						<xsl:when test="local-name(following-sibling::*[1])='ponctuation'">
							<xsl:if test="contains('([{«“‘&lsquo;',following-sibling::*[1])" >
								<xsl:text> </xsl:text>
							</xsl:if>
						</xsl:when>
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="numerique">
						<xsl:with-param name="mot" select="." />
						<xsl:with-param name="position" select="1" />
						<xsl:with-param name="positionPrec" select="0" />
						<xsl:with-param name="PNS" select="3" />
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="majuscule">
				<xsl:with-param name="mot" select="." />
				<xsl:with-param name="prefixe" select="0" />
				<xsl:with-param name="position" select="1" />
			</xsl:call-template>
			<xsl:choose>
				<xsl:when test="local-name(following-sibling::*[1])='mot'">
					<xsl:text> </xsl:text>
				</xsl:when>
				<!-- espaces avec les pponctuations -->
				<xsl:when test="local-name(following-sibling::*[1])='ponctuation'">
					<xsl:if test="contains('([{«“‘&lsquo;',following-sibling::*[1])" >
						<xsl:text> </xsl:text>
					</xsl:if>
				</xsl:when>
			</xsl:choose>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="numerique">
	<xsl:param name="mot"/>
	<xsl:param name="positionPrec"/>
	<xsl:param name="position"/>
	<xsl:param name="PNS"/>
	<xsl:param name="PNActif"/>
	<xsl:choose>
		<!-- on n'a pas encore lu tout le mot -->
		<xsl:when test="$position &lt; string-length(string($mot)) + 1">
			<xsl:choose>
				<!-- c'est un contenu numérique -->
				<xsl:when test="contains('0123456789+-×÷=,.&sup2;&sup3;',substring($mot,$position,1))">
					<xsl:choose>
						<!-- il y a autre chose que des chiffres -->
						<!--
						<xsl:when test="(contains('+-×÷=',substring($mot,$position,1)) or $PNS=0) and not(number(translate(substring-before($mot,$position),',0&sup2;&sup3;','.111')))">
						-->
						<xsl:when test="$PNS=0">
							<xsl:if test="not($position = 1)">
								<!-- on sépare la chaine en deux avant le signe num -->
								<xsl:call-template name="majuscule">
									<xsl:with-param name="mot" select="substring($mot,1,$position -1)" />
									<xsl:with-param name="prefixe" select="0" />
									<xsl:with-param name="position" select="1" />
									<xsl:with-param name="PN" select="1"/>
								</xsl:call-template>
								<xsl:if test="not(contains('&sup2;&sup3;',substring($mot,$position,1)))">
									<xsl:text>&pt6;</xsl:text>
								</xsl:if>
							</xsl:if>
							<xsl:choose>
								<!-- y a-t-il ambiguïté possible après? --><!-- ajouter test majuscule-->
								<xsl:when test="contains(substring(translate($mot,'ÂÊÎÔÛËÏÜŒWâêîôûëïüœw','ââââââââââââââââââââ'),$position + 1,string-length($mot)-$position +1),'â')">
									<!-- on transcrit le numérique -->
									<xsl:call-template name="majuscule">
										<xsl:with-param name="mot" select="substring($mot,$position,1)" />
										<xsl:with-param name="prefixe" select="0" />
										<xsl:with-param name="position" select="1" />
										<xsl:with-param name="PN" select="1"/>
									</xsl:call-template>
									<xsl:call-template name="IVB">
										<xsl:with-param name="mot" select="substring($mot,$position + 1,string-length($mot)-$position +1)"/>
										<xsl:with-param name="position" select="1"/>
									</xsl:call-template>
								</xsl:when>
								<xsl:otherwise>
									<xsl:choose>
										<xsl:when test="contains(translate(substring($mot,1,$position),'ABCDEFGHIJKLMNOPQRSTUVWXYZÀÂÉÈÊËÎÏÔÙÛÜ&Ccedil;&AElig;&OElig;','AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'),'A')"><!-- il y avait des majuscules avant -->
											<xsl:call-template name="majuscule">
												<xsl:with-param name="mot" select="substring($mot,$position, string-length($mot)-$position +1)" />
												<xsl:with-param name="prefixe" select="1" />
												<xsl:with-param name="position" select="1" />
												<xsl:with-param name="PN" select="1"/>
											</xsl:call-template>
										</xsl:when>
										<xsl:otherwise>
											<xsl:call-template name="majuscule">
												<xsl:with-param name="mot" select="substring($mot,$position, string-length($mot)-$position +1)" />
												<xsl:with-param name="prefixe" select="0" />
												<xsl:with-param name="position" select="1" />
												<xsl:with-param name="PN" select="1"/>
											</xsl:call-template>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:otherwise>
							</xsl:choose>
							<!-- espaces -->
							<xsl:choose>
								<xsl:when test="local-name(following-sibling::*[1])='mot'">
									<xsl:text> </xsl:text>
								</xsl:when>
								<!-- espaces avec les pponctuations -->
								<xsl:when test="local-name(following-sibling::*[1])='ponctuation'">
									<xsl:if test="contains('([{«“‘&lsquo;',following-sibling::*[1])" >
										<xsl:text> </xsl:text>
									</xsl:if>
								</xsl:when>
							</xsl:choose>
						</xsl:when>
						<!-- il n'y a que des chiffres et le mot est terminé -->
						<xsl:when test="$position = string-length(string($mot))"> <!--or number(translate(substring-after($mot,$position),',0&sup2;&sup3;','.111'))"> conversion des , en . et des 0, exp2 et 3 en 1 car number(0) et number(NNN,NNN) renvoie faux -->
							<xsl:call-template name="numerique">
								<xsl:with-param name="mot" select="$mot" />
								<xsl:with-param name="position" select="string-length(string($mot)) + 1" />
								<xsl:with-param name="positionPrec" select="1" />
								<xsl:with-param name="PNS" select="1"/>
								<xsl:with-param name="PNActif" select="$PNActif"/>
							</xsl:call-template>
						</xsl:when>
						<!-- il n'y a que des chiffres pour l'instant -->
						<xsl:otherwise>
							<xsl:call-template name="numerique">
								<xsl:with-param name="mot" select="$mot" />
								<xsl:with-param name="position" select="$position + 1" />
								<xsl:with-param name="PNS" select="1"/>
								<xsl:with-param name="PNActif" select="$PNActif"/>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
				<!-- le contenu n'est pas uniquement numérique ou pas numérique-->
					<xsl:choose>
						<!-- y avait-il un contenu numérique avant? -->
						<xsl:when test="$PNS = 1"><!-- oui -->
							<xsl:if test="not($PNActif = 1)">
								<xsl:text>&pt6;</xsl:text>
							</xsl:if>
							<xsl:choose>
								<!-- faut-il utiliser l'indicateur de valeur de base pour la suite? -->
								<xsl:when test="contains(substring(translate($mot,'ÂÊÎÔÛËÏÜŒWâêîôûëïüœw','ââââââââââââââââââââ'),$position,string-length($mot)-$position +1),'â')">
									<xsl:call-template name="majuscule">
										<xsl:with-param name="mot" select="substring($mot,1,$position - 1)" />
										<xsl:with-param name="prefixe" select="0" />
										<xsl:with-param name="position" select="1" />
										<xsl:with-param name="PN" select="1"/>
									</xsl:call-template>
									<xsl:call-template name="IVB">
										<xsl:with-param name="mot" select="substring($mot,$position,string-length($mot)-$position +1)"/>
										<xsl:with-param name="position" select="1"/>
									</xsl:call-template>
								</xsl:when>

								<xsl:otherwise>
									<xsl:call-template name="majuscule">
										<xsl:with-param name="mot" select="$mot" />
										<xsl:with-param name="prefixe" select="0" />
										<xsl:with-param name="position" select="1" />
										<xsl:with-param name="PN" select="1"/>
									</xsl:call-template>
									<!--espaces-->
									<xsl:choose>
										<xsl:when test="local-name(following-sibling::*[1])='mot'">
											<xsl:text> </xsl:text>
										</xsl:when>
										<!-- espaces avec les pponctuations -->
										<xsl:when test="local-name(following-sibling::*[1])='ponctuation'">
											<xsl:if test="contains('([{«“‘&lsquo;',following-sibling::*[1])" >
												<xsl:text> </xsl:text>
											</xsl:if>
										</xsl:when>
									</xsl:choose>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
						<xsl:otherwise>
							<!-- il n'y avait pas de contenu numérique avant -->
							<xsl:choose>
								<!-- il peut y avoir des ambiguités -->
								<xsl:when test="contains(substring(translate($mot,'ÂÊÎÔÛËÏÜŒWâêîôûëïüœw','ââââââââââââââââââââ'),1,$position),'â')">
									<xsl:call-template name="IVB">
										<xsl:with-param name="mot" select="$mot" />
										<xsl:with-param name="position" select="$position + 1" />
										<xsl:with-param name="PN" select="0"/>
									</xsl:call-template>
								</xsl:when>
								<xsl:otherwise>
									<xsl:call-template name="numerique">
										<xsl:with-param name="mot" select="$mot" />
										<xsl:with-param name="position" select="$position + 1" />
										<xsl:with-param name="PNS" select="0"/>
										<xsl:with-param name="PNActif" select="$PNActif"/>
									</xsl:call-template>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:when>
		<!-- on a lu le mot et il ne contient que des chiffres -->
		<xsl:otherwise>
			<xsl:choose>
				<xsl:when test="$PNS=1">
					<xsl:choose>
						<!-- on vérifie que le mot précédent n'était pas un nombre et qu'il n't a pas de symboles d'opération-->
						<xsl:when test="local-name(preceding-sibling::*[1])='mot' and number(translate(preceding-sibling::*[1],',0&sup2;&sup3;','.111')) and number(translate($mot,',0&sup2;&sup3;','.111'))"><!-- conversion des , en . et des 0 en 1 car number(0) et number(NNN,NNN) renvoie faux -->
							<xsl:text>&pt3;</xsl:text>
							<!--
							<xsl:call-template name="majuscule">
								<xsl:with-param name="mot" select="$mot" />
								<xsl:with-param name="prefixe" select="0" />
								<xsl:with-param name="position" select="1" />
							</xsl:call-template>-->
							<xsl:call-template name="symbolesComposes">
								<xsl:with-param name="mot" select="$mot"/>
								<xsl:with-param name="PN" select="$PNActif"/>
							</xsl:call-template>
							<xsl:choose>
								<xsl:when test="local-name(following-sibling::*[1])='mot' and not(number(translate(following-sibling::*[1],',0&sup2;&sup3;','.111')))"><!-- conversion des , en . et des 0 en 1 car number(0) et number(NNN,NNN) renvoie faux -->
									<xsl:text> </xsl:text>
								</xsl:when>
								<!-- espaces avec les pponctuations -->
								<xsl:when test="local-name(following-sibling::*[1])='ponctuation'">
									<xsl:if test="contains('([{«“‘&lsquo;',following-sibling::*[1])" >
										<xsl:text> </xsl:text>
									</xsl:if>
								</xsl:when>
							</xsl:choose>
						<!-- simplification 
						<xsl:when test="local-name(preceding::*[1])='mot' and contains('0123456789',substring(preceding::*[1], $positionPrec,1))">
							<xsl:choose>
								 on n'a pas encore vérifié tout le mot précédent 
								<xsl:when test="$positionPrec &lt; string-length(preceding::*[1])">
									<xsl:call-template name="numerique">
										<xsl:with-param name="mot" select="." />
										<xsl:with-param name="position" select="$position" />
										<xsl:with-param name="positionPrec" select="$positionPrec + 1" />
										<xsl:with-param name="PNS" select="1"/>
									</xsl:call-template>
								</xsl:when>
								 on a lu tout le mot précédent et il ne contient que des chiffres 
								<xsl:otherwise>
									<xsl:text>&pt3;</xsl:text>
									<xsl:call-template name="majuscule">
										<xsl:with-param name="mot" select="string(.)" />
										<xsl:with-param name="prefixe" select="0" />
										<xsl:with-param name="position" select="1" />
									</xsl:call-template>
								</xsl:otherwise>
							</xsl:choose>-->
						</xsl:when>
						<!-- le mot précédent n'est pas composé uniquement de 0123456789 -->
						<xsl:otherwise>
							<xsl:if test="not($PNActif = 1)">
								<xsl:text>&pt6;</xsl:text>
							</xsl:if>
							<!--
							<xsl:call-template name="majuscule">
								<xsl:with-param name="mot" select="$mot" />
								<xsl:with-param name="prefixe" select="0" />
								<xsl:with-param name="position" select="1" />
								<xsl:with-param name="PN" select="1"/>
							</xsl:call-template>-->
							<xsl:call-template name="symbolesComposes">
								<xsl:with-param name="mot" select="$mot"/>
								<xsl:with-param name="PN" select="$PNActif"/>
							</xsl:call-template>
							<!-- espaces -->
							<xsl:choose>
								<xsl:when test="local-name(following-sibling::*[1])='mot' and (not(number(translate(following-sibling::*[1],',0&sup2;&sup3;','.111'))) and number(translate($mot,',0&sup2;&sup3;','.111')) or ( not(number(translate($mot,',0&sup2;&sup3;','.111')))))"><!-- conversion des , en . et des 0 en 1 car number(0) et number(NNN,NNN) renvoie faux -->
									<xsl:text> </xsl:text>
								</xsl:when>
								<!-- espaces avec les pponctuations -->
								<xsl:when test="local-name(following-sibling::*[1])='ponctuation'">
									<xsl:if test="contains('([{«“‘&lsquo;',following-sibling::*[1])" >
										<xsl:text> </xsl:text>
									</xsl:if>
								</xsl:when>
							</xsl:choose>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="majuscule">
						<xsl:with-param name="mot" select="$mot" />
						<xsl:with-param name="prefixe" select="0" />
						<xsl:with-param name="position" select="1" />
					</xsl:call-template>
					<!-- espaces-->
					<xsl:choose>
						<xsl:when test="local-name(following-sibling::*[1])='mot'">
							<xsl:text> </xsl:text>
						</xsl:when>
						<!-- espaces avec les pponctuations -->
						<xsl:when test="local-name(following-sibling::*[1])='ponctuation'">
							<xsl:if test="contains('([{«“‘&lsquo;',following-sibling::*[1])" >
								<xsl:text> </xsl:text>
							</xsl:if>
						</xsl:when>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="IVB">
	<xsl:param name="mot"/>
	<xsl:param name="position"/>
	<xsl:param name="PN"/>
	<xsl:choose>
		<xsl:when test="$position = string-length($mot)">
			<xsl:if test="contains(translate($mot,'ÂÊÎÔÛËÏÜŒWâêîôûëïüœw','ââââââââââââââââââââ'),'â')">
				<xsl:text>&pt56;</xsl:text>
				<xsl:call-template name="majuscule">
					<xsl:with-param name="mot" select="$mot" />
					<xsl:with-param name="prefixe" select="0" />
					<xsl:with-param name="position" select="1" />
					<xsl:with-param name="PN" select="0"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:when>
		<!-- on cherche le contenu numérique -->
		<xsl:when test="contains('0123456789+-×÷=,.&sup2;&sup3;',substring($mot,$position,1))">
			<xsl:choose>
				<xsl:when  test="contains(substring(translate($mot,'ÂÊÎÔÛËÏÜŒWâêîôûëïüœw','ââââââââââââââââââââ'),1,$position - 1),'â')">
					<xsl:if test="not($PN = 0)">
						<xsl:text>&pt56;</xsl:text>
					</xsl:if>
					<xsl:call-template name="majuscule">
						<xsl:with-param name="mot" select="substring($mot,1,$position - 1)" />
						<xsl:with-param name="prefixe" select="0" />
						<xsl:with-param name="position" select="1" />
						<xsl:with-param name="PN" select="0"/>
					</xsl:call-template>
					<xsl:call-template name="numerique">
						<xsl:with-param name="mot" select="substring($mot,$position,string-length($mot) - $position + 1)" />
						<xsl:with-param name="position" select="1" />
						<xsl:with-param name="positionPrec" select="0" />
						<xsl:with-param name="PNS" select="3" />
						<xsl:with-param name="PNActif" select="0"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="majuscule">
						<xsl:with-param name="mot" select="substring($mot,1,$position - 1)" />
						<xsl:with-param name="prefixe" select="0" />
						<xsl:with-param name="position" select="1" />
						<xsl:with-param name="PN" select="1"/>
					</xsl:call-template>
					<xsl:if test="not($position = string-length($mot))">
						<xsl:call-template name="numerique">
							<xsl:with-param name="mot" select="substring($mot,$position,string-length($mot) - $position + 1)" />
							<xsl:with-param name="position" select="1" />
							<xsl:with-param name="positionPrec" select="0" />
							<xsl:with-param name="PNS" select="3" />
							<xsl:with-param name="PNActif" select="1"/>
						</xsl:call-template>
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="IVB">
				<xsl:with-param name="mot" select="$mot"/>
				<xsl:with-param name="position" select="$position + 1"/>
				<xsl:with-param name="PN" select="$PN"/>
			</xsl:call-template>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- ***************************************************
		MAJUSCULES
	*************************************************
-->

<xsl:template name="majuscule">
	<xsl:param name="mot"/>
	<xsl:param name="prefixe"/>
	<xsl:param name="position"/>
	<xsl:param name="PN"/>
	<xsl:param name="passage" select='1'/>
	<xsl:choose>
		<!-- le mot ne contient pas de minuscules ni de chiffres ou bien est potentiellement dans un passage-->
		<xsl:when test="not(contains(translate($mot,'&sup2;&sup3;abcdefghijklmnopqrstuvwxyzàâéèêëîïôùûü&cedil;&aelig;&oelig;','aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa'),'a')) and not($passage = '0')">
		<!--not(contains($mot,'abcdefghijklmnopqrstuvwxyzz'))">-->
			<xsl:choose>
				<!-- le mot ne contient pas de majuscules-->
				<xsl:when test="not(contains(translate($mot,'ABCDEFGHIJKLMNOPQRSTUVWXYZÀÂÉÈÊËÎÏÔÙÛÜ&Ccedil;&AElig;&OElig;','AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'),'A'))">
					<xsl:call-template name="symbolesComposes">
							<xsl:with-param name="mot" select="string($mot)"/>
							<xsl:with-param name="PN" select="$PN"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<!-- on va utiliser une variable pour savoir si c'est le premier mot en majuscule d'un passage -->
					 <xsl:variable name="position1MotMaj">
						<xsl:call-template name="donnePosition1MotMaj">
							<xsl:with-param name="position" select="1" />
						</xsl:call-template>
					</xsl:variable>
					 <xsl:variable name="positionDMotMaj">
						<xsl:call-template name="donnePositionDMotMaj">
							<xsl:with-param name="position" select="1" />
						</xsl:call-template>
					</xsl:variable>
					<xsl:choose>
						<!-- le mot est-il dans un passage en majuscule? -->
						<!-- c'est le 1er mot d'un passage en majuscule -->
						<xsl:when test="$position1MotMaj ='1' and $positionDMotMaj = '1'">
						<!-- on n'est pas dans un passage en majuscule -->
							<xsl:call-template name="majuscule">
								<xsl:with-param name="mot" select="$mot" />
								<xsl:with-param name="prefixe" select="$prefixe" />
								<xsl:with-param name="position" select="$position" />
								<xsl:with-param name="PN" select="$PN"/>
								<xsl:with-param name="passage" select="0"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:when test="$position1MotMaj = '1'">
							<!-- y a-t-il au moins 3 autres mots suivants en majuscules?-->
							<xsl:variable name="premierMotPassageMaj">
								<xsl:call-template name="estSuiviMaj">
									<xsl:with-param name="nb" select="3"/>
									<xsl:with-param name="position" select="1"/>
								</xsl:call-template>
							</xsl:variable>
							<xsl:choose>
								<xsl:when test="$premierMotPassageMaj = '1'">
									<xsl:text>&pt25;&pt46;</xsl:text>
									<xsl:call-template name="symbolesComposes">
										<xsl:with-param name="mot" select="$mot"/>
										<xsl:with-param name="PN" select="$PN"/>
									</xsl:call-template>
								</xsl:when>
								<xsl:otherwise>
									<xsl:call-template name="majuscule">
										<xsl:with-param name="mot" select="$mot" />
										<xsl:with-param name="prefixe" select="$prefixe" />
										<xsl:with-param name="position" select="$position" />
										<xsl:with-param name="PN" select="$PN"/>
										<xsl:with-param name="passage" select="0"/>
									</xsl:call-template>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
						<xsl:when test="$positionDMotMaj = '1'">
						<!-- dernier mot -->
							<xsl:variable name="dernierMotPassageMaj">
								<xsl:call-template name="estPrecedeMaj">
									<xsl:with-param name="nb" select="3"/>
									<xsl:with-param name="position" select="1"/>
								</xsl:call-template>
							</xsl:variable>
							<xsl:choose>
								<xsl:when test="$dernierMotPassageMaj = '1'">
									<xsl:text>&pt46;</xsl:text>
									<xsl:call-template name="symbolesComposes">
										<xsl:with-param name="mot" select="$mot"/>
										<xsl:with-param name="PN" select="$PN"/>
									</xsl:call-template>
								</xsl:when>
								<xsl:otherwise>
									<xsl:call-template name="majuscule">
										<xsl:with-param name="mot" select="$mot" />
										<xsl:with-param name="prefixe" select="$prefixe" />
										<xsl:with-param name="position" select="$position" />
										<xsl:with-param name="PN" select="$PN"/>
										<xsl:with-param name="passage" select="0"/>
									</xsl:call-template>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
						<!--
						<xsl:when test="$position1MotMaj = '3'">
							<xsl:text>2ème</xsl:text>
							<xsl:call-template name="symbolesComposes">
								<xsl:with-param name="mot" select="$mot"/>
								<xsl:with-param name="PN" select="$PN"/>
							</xsl:call-template>
						</xsl:when>-->
						<xsl:otherwise>
							<!-- ni le premier ni le dernier, est-ce un passage? -->
							<xsl:variable name="nbSuivant">
								<xsl:call-template name="estSuiviMaj">
									<xsl:with-param name="nb" select="2"/>
									<xsl:with-param name="position" select="1"/>
								</xsl:call-template>
							</xsl:variable>
							<xsl:variable name="nbPrec">
								<xsl:call-template name="estPrecedeMaj">
									<xsl:with-param name="nb" select="2"/>
									<xsl:with-param name="position" select="1"/>
								</xsl:call-template>
							</xsl:variable>
							<xsl:choose>
								<xsl:when test="$nbSuivant + $nbPrec = 0">
								<!-- passage pas en majuscule -->
									<xsl:call-template name="majuscule">
										<xsl:with-param name="mot" select="$mot" />
										<xsl:with-param name="prefixe" select="$prefixe" />
										<xsl:with-param name="position" select="$position" />
										<xsl:with-param name="PN" select="$PN"/>
										<xsl:with-param name="passage" select="0"/>
									</xsl:call-template>
								</xsl:when>
								<xsl:otherwise>
									<xsl:call-template name="symbolesComposes">
										<xsl:with-param name="mot" select="$mot"/>
										<xsl:with-param name="PN" select="$PN"/>
									</xsl:call-template>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:when>
		<xsl:otherwise>
			<!-- traitement d'un mot contenant des majuscules mais pas dans un passage -->
			<xsl:choose>
				<xsl:when test="not(contains(translate($mot,'abcdefghijklmnopqrstuvwxyzàâéèêëîïôùûü&ccedil;&aelig;&oelig;','aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa'),'a'))">
				<!-- le mot est entièrement en majuscule et contient au minimum une majuscule-->
					<xsl:choose>
						<!-- le mot commence par un numérique -->
						<xsl:when test="contains(translate(substring($mot, 1, 1), '0123456789', '1111111111'),'1')">
							<xsl:call-template name="symbolesComposes">
								<xsl:with-param name="mot" select="substring($mot, 1, 1)"/>
								<xsl:with-param name="PN" select="$PN"/>
							</xsl:call-template>
							<xsl:call-template name="majuscule">
								<xsl:with-param name="mot" select="substring($mot, 2, string-length($mot) - 1)" />
								<xsl:with-param name="prefixe" select="0" />
								<xsl:with-param name="position" select="1" />
								<xsl:with-param name="PN" select="$PN"/>
								<xsl:with-param name="passage" select="0"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:otherwise>
							<xsl:if test="contains(translate($mot,'ABCDEFGHIJKLMNOPQRSTUVWXYZÀÂÉÈÊËÎÏÔÙÛÜ&Ccedil;&AElig;&OElig;','AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'),'A') and not($prefixe= 1)">
								<xsl:if test="not(string-length(translate($mot, 'ABCDEFGHIJKLMNOPQRSTUVWXYZÀÂÉÈÊËÎÏÔÙÛÜ&Ccedil;&AElig;&OElig;','')) = string-length($mot) - 1)"><!-- il y a plus d'une majuscule-->
									<xsl:value-of select="translate($mot, 'ABCDEFGHIJKLMNOPQRSTUVWXYZÀÂÉÈÊËÎÏÔÙÛÜ&Ccedil;&AElig;&OElig;','')"/>
									<xsl:text>&pt46;</xsl:text>
								</xsl:if>
								<xsl:text>&pt46;</xsl:text>
							</xsl:if>
							<xsl:call-template name="symbolesComposes">
								<xsl:with-param name="mot" select="$mot"/>
								<xsl:with-param name="PN" select="$PN"/>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="$position > string-length($mot)">
					<!-- c'est fini: on fait rien -->
					<!--<xsl:if test="$prefixe = 0">
						<xsl:text>&pt46;</xsl:text>
						<xsl:if test="string-length(.) > 1">
							<xsl:text>&pt46;</xsl:text>
						</xsl:if>
						<xsl:call-template name="symbolesComposes">
							<xsl:with-param name="mot" select="string(.)"/>
							<xsl:with-param name="PN" select="$PN"/>
						</xsl:call-template>
					</xsl:if>-->
				</xsl:when>
				<xsl:when test="$prefixe = 1">
					<xsl:if test="contains('ABCDEFGHIJKLMNOPQRSTUVWXYZÀÂÉÈÊËÎÏÔÙÛÜ&Ccedil;&AElig;&OElig;',substring(string($mot),$position,1))">
						<xsl:text>&pt46;</xsl:text>
					</xsl:if>
					<xsl:call-template name="symbolesComposes">
						<xsl:with-param name="mot" select="substring(string($mot),$position,1)"/>
						<xsl:with-param name="PN" select="$PN"/>
					</xsl:call-template>
					<xsl:call-template name="majuscule">
						<xsl:with-param name="mot" select="$mot" />
						<xsl:with-param name="prefixe" select="1" />
						<xsl:with-param name="position" select="$position + 1" />
						<xsl:with-param name="PN" select="$PN"/>
						<xsl:with-param name="passage" select="0"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="not(contains(translate(substring(string($mot),$position,1),'abcdefghijklmnopqrstuvwxyzàâéèêëîïôùûü&ccedil;&aelig;&oelig;','aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa'),'a'))">
					<xsl:call-template name="majuscule">
						<xsl:with-param name="mot" select="$mot" />
						<xsl:with-param name="prefixe" select="0" />
						<xsl:with-param name="position" select="$position + 1" />
						<xsl:with-param name="PN" select="$PN"/>
						<xsl:with-param name="passage" select="0"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
		<!---->
					<!-- on recommence au début du mot et cette fois on préfixe toutes les majuscules -->
		<!---->
					<xsl:choose>
						<xsl:when test="$position + 1 &lt; string-length($mot)">
							<xsl:call-template name="majuscule">
								<xsl:with-param name="mot" select="substring(string($mot), 1, $position)" />
								<xsl:with-param name="prefixe" select="1" />
								<xsl:with-param name="position" select="1" />
								<xsl:with-param name="PN" select="$PN"/>
								<xsl:with-param name="passage" select="0"/>
							</xsl:call-template>
							<xsl:call-template name="majuscule">
								<xsl:with-param name="mot" select="substring(string($mot), $position + 1, string-length($mot) - $position)" />
								<xsl:with-param name="prefixe" select="0" />
								<xsl:with-param name="position" select="1" />
								<xsl:with-param name="PN" select="$PN"/>
								<xsl:with-param name="passage" select="0"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="majuscule">
								<xsl:with-param name="mot" select="string($mot)" />
								<xsl:with-param name="prefixe" select="1" />
								<xsl:with-param name="position" select="1" />
								<xsl:with-param name="PN" select="$PN"/>
								<xsl:with-param name="passage" select="0"/>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="donnePosition1MotMaj">
	<!-- 
		renvoie 0 si le mot n'est pas dans un passage en majuscule
		renvoie 1 si le mot est le premier d'un passage en majuscule
		renvoie 2 si le mot est le dernier d'un passage en majuscule
		renvoie 3 si le mot précédent est en majuscule -->
	<xsl:param name="position"/>
	<xsl:choose>
		<!-- on cherche le premier mot en majuscule précédent si il existe, ou si il y a un mot en minuscule avant -->
		<xsl:when test="count(preceding::*)=0">
		<!-- c'est le debut du document -->
			<xsl:value-of select="1"/>
		</xsl:when>
		<xsl:when test="not(local-name(preceding::*[$position])='mot') or (local-name(preceding::*[$position])='mot' and string(preceding::*[$position]) = $chaine_vide)">
		<!--pas intéressant-->
			<xsl:call-template name="donnePosition1MotMaj">
				<xsl:with-param name="position" select="$position + 1"/>
			</xsl:call-template>
		</xsl:when>
		<!-- interessant et pas en majuscule -->
		<xsl:when test="contains(translate(preceding::*[$position],'&sup2;&sup3;0123456789abcdefghijklmnopqrstuvwxyzàâéèêëîïôùûü&ccedil;&aelig;&oelig;','aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa'),'a')">
 			<xsl:value-of select="1"/>
		</xsl:when>
		<!-- intéressant, en majuscule? -->
		<xsl:when test="contains(translate(preceding::*[$position],'ABCDEFGHIJKLMNOPQRSTUVWXYZÀÂÉÈÊËÎÏÔÙÛÜ&Ccedil;&AElig;&OElig;','AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'),'A')">
 			<xsl:value-of select="0"/>
		</xsl:when>
		<xsl:otherwise>
			<!-- intéressant, ni en majuscule ni en minuscule -->
			<xsl:value-of select="0"/>
			<!--<xsl:call-template name="donnePosition1MotMaj">
				<xsl:with-param name="position" select="$position + 1"/>
			</xsl:call-template>-->
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="donnePositionDMotMaj">
	<!-- 
		renvoie 0 si le mot n'est pas le dernier d'un passage en majuscule
		renvoie 1 si le mot est le dernier d'un passage en majusculee -->
	<xsl:param name="position"/>
	<xsl:choose>
		<!-- on cherche le premier mot en majuscule suivant si il existe, ou si il y a un mot en minuscule avant -->
		<xsl:when test="count(following::*)=0">
		<!-- c'est la fin du document -->
			<xsl:value-of select="1"/>
		</xsl:when>
		<xsl:when test="not(local-name(following::*[$position])='mot') or (local-name(following::*[$position])='mot' and string(following::*[$position]) = $chaine_vide)">
		<!--pas intéressant-->
			<xsl:call-template name="donnePositionDMotMaj">
				<xsl:with-param name="position" select="$position + 1"/>
			</xsl:call-template>
		</xsl:when>
		<!-- interessant et pas en majuscule -->
		<xsl:when test="contains(translate(following::*[$position],'&sup2;&sup3;0123456789abcdefghijklmnopqrstuvwxyzàâéèêëîïôùûü&ccedil;&aelig;&oelig;','aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa'),'a')">
 			<xsl:value-of select="1"/>
		</xsl:when>
		<!-- intéressant, en majuscule? -->
		<xsl:when test="contains(translate(following::*[$position],'ABCDEFGHIJKLMNOPQRSTUVWXYZÀÂÉÈÊËÎÏÔÙÛÜ&Ccedil;&AElig;&OElig;','AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'),'A')">
 			<xsl:value-of select="0"/>
		</xsl:when>
		<xsl:otherwise>
			<!-- intéressant, ni en majuscule ni en minuscule -->
			<xsl:value-of select="0"/>
			<!--
			<xsl:call-template name="donnePositionDMotMaj">
				<xsl:with-param name="position" select="$position + 1"/>
			</xsl:call-template>-->
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="estSuiviMaj">
	<xsl:param name="nb"/>
	<xsl:param name="position"/>
	<!-- renvoie 1 si il y a nb mot en majuscule au moins après le mot -->
	<xsl:choose>
		<xsl:when test="$nb = 0">
			<xsl:value-of select="1"/>
		</xsl:when>
		<xsl:when test="count(following::mot) &lt; $nb">
		<!-- c'est la fin du document -->
			<xsl:value-of select="0"/>
		</xsl:when>
		<xsl:when test="not(local-name(following::*[$position])='mot') or (local-name(following::*[$position])='mot' and string(following::*[$position]) = $chaine_vide)">
		<!--pas intéressant-->
			<xsl:choose>
				<xsl:when test="local-name(following::*[$position])='mot' and string(following::*[$position]) = $chaine_vide">
				<!-- on ajoute un mot pour ignorer le mot vide -->
					<xsl:call-template name="estSuiviMaj">
						<xsl:with-param name="position" select="$position + 1"/>
						<xsl:with-param name="nb" select="$nb + 1"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="estSuiviMaj">
						<xsl:with-param name="position" select="$position + 1"/>
						<xsl:with-param name="nb" select="$nb"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:when>
		<!-- interessant et pas en majuscule -->
		<xsl:when test="contains(translate(following::*[$position],'&sup2;&sup3;0123456789abcdefghijklmnopqrstuvwxyzàâéèêëîïôùûü&ccedil;&aelig;&oelig;','aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa'),'a')">
 			<xsl:value-of select="0"/>
		</xsl:when>
		<!-- intéressant, en majuscule? -->
		<xsl:when test="contains(translate(following::*[$position],'ABCDEFGHIJKLMNOPQRSTUVWXYZÀÂÉÈÊËÎÏÔÙÛÜ&Ccedil;&AElig;&OElig;','AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'),'A')">
 			<xsl:call-template name="estSuiviMaj">
				<xsl:with-param name="position" select="$position + 1"/>
				<xsl:with-param name="nb" select="$nb - 1"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="estSuiviMaj">
				<xsl:with-param name="position" select="$position + 1"/>
				<xsl:with-param name="nb" select="$nb"/>
			</xsl:call-template>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="estPrecedeMaj">
	<xsl:param name="nb"/>
	<xsl:param name="position"/>
	<!-- renvoie 1 si il y a nb mot en majuscule au moins après le mot -->
	<xsl:choose>
		<xsl:when test="$nb = 0">
			<xsl:value-of select="1"/>
		</xsl:when>
		<xsl:when test="count(preceding::mot) &lt; $nb">
		<!-- c'est la fin du document -->
			<xsl:value-of select="0"/>
		</xsl:when>
		<xsl:when test="not(local-name(preceding::*[$position])='mot') or (local-name(preceding::*[$position])='mot' and string(preceding::*[$position]) = $chaine_vide)">
		<!--pas intéressant-->
			<xsl:choose>
				<xsl:when test="local-name(preceding::*[$position])='mot' and string(preceding::*[$position]) = $chaine_vide">
				<!-- on ajoute un mot pour ignorer le mot vide -->
					<xsl:call-template name="estPrecedeMaj">
						<xsl:with-param name="position" select="$position + 1"/>
						<xsl:with-param name="nb" select="$nb + 1"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="estPrecedeMaj">
						<xsl:with-param name="position" select="$position + 1"/>
						<xsl:with-param name="nb" select="$nb"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:when>
		<!-- interessant et pas en majuscule -->
		<xsl:when test="contains(translate(preceding::*[$position],'&sup2;&sup3;0123456789abcdefghijklmnopqrstuvwxyzàâéèêëîïôùûü&ccedil;&aelig;&oelig;','aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa'),'a')">
 			<xsl:value-of select="0"/>
		</xsl:when>
		<!-- intéressant, en majuscule? -->
		<xsl:when test="contains(translate(preceding::*[$position],'ABCDEFGHIJKLMNOPQRSTUVWXYZÀÂÉÈÊËÎÏÔÙÛÜ&Ccedil;&AElig;&OElig;','AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'),'A')">
 			<xsl:call-template name="estPrecedeMaj">
				<xsl:with-param name="position" select="$position + 1"/>
				<xsl:with-param name="nb" select="$nb - 1"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="estPrecedeMaj">
				<xsl:with-param name="position" select="$position + 1"/>
				<xsl:with-param name="nb" select="$nb"/>
			</xsl:call-template>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- ***************************************************
		SYMBOLES COMPOSES
	*************************************************
-->

<xsl:template name="symbolesComposes">
	<xsl:param name="mot"/>
	<xsl:param name="PN"/>
	<xsl:choose>
		<xsl:when test="contains(translate(string($mot),'–©°§®™&amp;~*#%‰_\¢€£$¥&lt;&gt;≤≥²³&sup2;&sup3;','aaaaaaaaaaaaaaaaaaaaaaaaaaa'),'a')">
			<xsl:choose>
				<xsl:when test="substring($mot,1,1)='–'">
					<xsl:text>&pt36;&pt36;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='©'">
					<xsl:text>&pt5;&pt14;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='°'">
					<xsl:text>&pt5;&pt135;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='§'">
					<xsl:text>&pt5;&pt1234;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='®'">
					<xsl:text>&pt5;&pt1235;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='™'">
					<xsl:text>&pt5;&pt2345;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='&amp;'">
					<xsl:text>&pt5;&pt123456;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='~'">
					<xsl:text>&pt5;&pt26;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='*'">
					<xsl:text>&pt5;&pt35;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='#'">
					<xsl:text>&pt5;&pt3456;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='%'">
					<xsl:text>&pt5;&pt346;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='‰'">
					<xsl:text>&pt5;&pt346;&pt346;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='_'">
					<xsl:text>&pt5;&pt36;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='\'">
					<xsl:text>&pt5;&pt34;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='¢'">
					<xsl:text>&pt45;&pt14;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='€'">
					<xsl:text>&pt45;&pt15;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='£'">
					<xsl:text>&pt45;&pt123;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='$'">
					<xsl:text>&pt45;&pt234;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='¥'">
					<xsl:text>&pt45;&pt13456;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='&lt;'">
					<xsl:text>&pt5;&pt126;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='&gt;'">
					<xsl:text>&pt5;&pt345;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='≤'">
					<xsl:text>&pt45;&pt126;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='≥'">
					<xsl:text>&pt45;&pt345;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='²' or substring($mot,1,1)='&sup2;'">
					<xsl:text>&pt4;&pt126;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='³' or substring($mot,1,1)='&sup3;'">
					<xsl:text>&pt4;&pt146;</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="bijection">
						<xsl:with-param name="mot" select="substring($mot,1,1)"/>
						<xsl:with-param name="PN" select="$PN"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:if test="string-length($mot) &gt; 1">
				<xsl:call-template name="symbolesComposes">
					<xsl:with-param name="mot" select="substring($mot,2,string-length($mot))"/>
					<xsl:with-param name="PN" select="$PN"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="bijection">
				<xsl:with-param name="mot" select="string($mot)"/>
				<xsl:with-param name="PN" select="$PN"/>
			</xsl:call-template>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="bijection">
	<xsl:param name="mot"/>
	<xsl:param name="PN"/>
	<xsl:choose>
		<xsl:when test='string($mot)="&apos;"'>
			<xsl:text><!--&pt2356;-->&pt3;</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<!-- utilisation d'une variable (pb des '")-->
			<xsl:variable name="v2">
				<xsl:text>&pt1;&pt12;&pt14;&pt145;&pt15;&pt124;&pt1245;&pt125;&pt24;&pt245;&pt13;&pt123;&pt134;&pt1345;&pt135;&pt1234;&pt12345;&pt1235;&pt234;&pt2345;&pt136;&pt1236;&pt2456;&pt1346;&pt13456;&pt1356;&pt12356;&pt16;&pt123456;&pt2346;&pt126;&pt1246;&pt146;&pt12456;&pt1456;&pt23456;&pt156;&pt1256;&pt12346;&pt345;&pt246;&pt1;&pt12;&pt14;&pt145;&pt15;&pt124;&pt1245;&pt125;&pt24;&pt245;&pt13;&pt123;&pt134;&pt1345;&pt135;&pt1234;&pt12345;&pt1235;&pt234;&pt2345;&pt136;&pt1236;&pt2456;&pt1346;&pt13456;&pt1356;&pt3456;&pt16;&pt126;&pt146;&pt1456;&pt156;&pt1246;&pt12456;&pt1256;&pt246;&pt12356;&pt16;&pt123456;&pt2346;&pt126;&pt1246;&pt146;&pt12456;&pt1456;&pt23456;&pt156;&pt1256;&pt12346;&pt345;&pt246;&pt345;&pt235;&pt36;&pt35;&pt25;&pt2356;&pt256;&pt2;</xsl:text>
			</xsl:variable>
			<xsl:value-of select="translate(string($mot),'ABCDEFGHIJKLMNOPQRSTUVWXYZÀÂÉÈÊËÎÏÔÙÛÜ&Ccedil;&AElig;&OElig;abcdefghijklmnopqrstuvwxyz0123456789àâéèêëîïôùûüçæœ@+-×÷=.,&nbsp;',string($v2))" />
			<!-- ne rien mettre pour &nbsp-->
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

</xsl:stylesheet>